package com.hzya.frame.seeyon.cbs8.service.impl;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.basedao.service.impl.BaseService;
import com.hzya.frame.cbs8.util.PayState;
import com.hzya.frame.seeyon.cbs8.dao.ICbsLogDao;
import com.hzya.frame.seeyon.cbs8.entity.CbsLogEntity;
import com.hzya.frame.seeyon.cbs8.entity.PaymentEntity;
import com.hzya.frame.seeyon.cbs8.service.ICbsLogService;
import com.hzya.frame.web.exception.BaseSystemException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description cbs8支付日志
 * @Author xiangerlin
 * @Date 2024/6/14 17:22
 **/
@Service()
public class CbsLogServiceImpl extends BaseService<CbsLogEntity,String> implements ICbsLogService {

    Logger log = LoggerFactory.getLogger(getClass());

    private ICbsLogDao cbsLogDao;

    @Autowired
    public void setCbsLogDao(ICbsLogDao cbsLogDao) {
        this.cbsLogDao = cbsLogDao;
        this.dao = cbsLogDao;
    }

    /**
     * 查询支付中的数据
     *
     * @param logEntity
     * @return
     */
    @Override
    public List<CbsLogEntity> queryInPayment(CbsLogEntity logEntity) {
        List<CbsLogEntity> logList = cbsLogDao.queryList(logEntity, "CbsLogEntity_list_base_in_payment");
        return logList;
    }

    /**
     * 保存日志，通过rest接口的形式
     *
     * @param logEntity
     */
    @Override
    public void saveLog(CbsLogEntity logEntity) {

    }

    /**
     * 补推，从自己开发的页面或者APIpost
     * 需要传oa表单id和表单编号
     *
     * @param entity
     */
    @Override
    public void retry(CbsLogEntity entity) {
        PaymentEntity paymentEntity = new PaymentEntity();
        paymentEntity.setOaId(entity.getOa_id());
        paymentEntity.setReferenceNum(entity.getBill_code());
        CbsLogEntity logEntity = new CbsLogEntity();
        logEntity.setId(entity.getId());
        logEntity = cbsLogDao.queryOne(logEntity);
        String pay_state = logEntity.getPay_state();
        if (PayState.h.getValue().equals(pay_state)
                || PayState.three.getValue().equals(pay_state)
                || PayState.k.getValue().equals(pay_state)
                || "推送失败".equals(pay_state)){
            //todo 调用重试方法
        }else {
            throw new BaseSystemException("只允许补推支付失败的记录");
        }
    }

    /**
     * 补推，从OA页面
     * 只需要传日志表id就行
     *
     * @param jsonObject
     */
    @Override
    public void resend(JSONObject jsonObject) {
        if (null != jsonObject && StrUtil.isNotEmpty(jsonObject.getString("id"))){
            String id = jsonObject.getString("id");
            CbsLogEntity cbsLogEntity = new CbsLogEntity();
            cbsLogEntity.setId(id);
            cbsLogEntity =cbsLogDao.queryOne(cbsLogEntity);
            if (null != cbsLogEntity && StrUtil.isNotEmpty(cbsLogEntity.getOa_id()) && StrUtil.isNotEmpty(cbsLogEntity.getBill_code())){
                retry(cbsLogEntity);
            }
        }
    }

    //获取xml模板
    private String getXmlTemplate(){
        // return "<forms  version=\"2.1\"><formExport><summary  id=\"859338107516044243\" name=\"formmain_1283\"/><definitions><column  id=\"field0001\" type=\"0\" name=\"单据ID\" isNullable=\"false\" length=\"100\"/><column  id=\"field0002\" type=\"0\" name=\"单据编号\" isNullable=\"false\" length=\"100\"/><column  id=\"field0003\" type=\"0\" name=\"英文表名\" isNullable=\"false\" length=\"100\"/><column  id=\"field0004\" type=\"0\" name=\"中文表名\" isNullable=\"false\" length=\"100\"/><column  id=\"field0005\" type=\"0\" name=\"支付状态\" isNullable=\"false\" length=\"100\"/><column  id=\"field0006\" type=\"0\" name=\"支付信息\" isNullable=\"false\" length=\"100\"/><column  id=\"field0007\" type=\"0\" name=\"支付申请状态\" isNullable=\"false\" length=\"100\"/><column  id=\"field0008\" type=\"0\" name=\"成功标记\" isNullable=\"false\" length=\"100\"/></definitions><values><column  name=\"单据ID\"><value><![CDATA[{}]]></value></column><column  name=\"单据编号\"><value><![CDATA[{}]]></value></column><column  name=\"英文表名\"><value><![CDATA[{}]]></value></column><column  name=\"中文表名\"><value><![CDATA[{}]]></value></column><column  name=\"支付状态\"><value><![CDATA[{}]]></value></column><column  name=\"支付信息\"><value><![CDATA[{}]]></value></column><column  name=\"支付申请状态\"><value><![CDATA[{}]]></value></column><column  name=\"成功标记\"><value><![CDATA[{}]]></value></column></values><subForms/></formExport></forms>";
        return "<forms  version=\"2.1\"><formExport><summary  id=\"859338107516044243\" name=\"formmain_1283\"/><definitions><column  id=\"field0001\" type=\"0\" name=\"单据ID\" isNullable=\"false\" length=\"100\"/><column  id=\"field0002\" type=\"0\" name=\"单据编号\" isNullable=\"false\" length=\"100\"/><column  id=\"field0003\" type=\"0\" name=\"英文表名\" isNullable=\"false\" length=\"100\"/><column  id=\"field0004\" type=\"0\" name=\"中文表名\" isNullable=\"false\" length=\"100\"/><column  id=\"field0005\" type=\"0\" name=\"支付状态\" isNullable=\"false\" length=\"100\"/><column  id=\"field0006\" type=\"0\" name=\"支付信息\" isNullable=\"false\" length=\"100\"/><column  id=\"field0007\" type=\"0\" name=\"支付申请状态\" isNullable=\"false\" length=\"100\"/><column  id=\"field0008\" type=\"0\" name=\"成功标记\" isNullable=\"false\" length=\"100\"/><column  id=\"field0009\" type=\"0\" name=\"流程标题\" isNullable=\"false\" length=\"255\"/><column  id=\"field0010\" type=\"0\" name=\"请款主体\" isNullable=\"false\" length=\"100\"/><column  id=\"field0011\" type=\"0\" name=\"收款对象\" isNullable=\"false\" length=\"100\"/><column  id=\"field0012\" type=\"4\" name=\"金额\" isNullable=\"false\" length=\"20\"/><column  id=\"field0013\" type=\"0\" name=\"CBS支付申请单号\" isNullable=\"false\" length=\"100\"/></definitions><values><column  name=\"单据ID\"><value><![CDATA[{}]]></value></column><column  name=\"单据编号\"><value><![CDATA[{}]]></value></column><column  name=\"英文表名\"><value><![CDATA[{}]]></value></column><column  name=\"中文表名\"><value><![CDATA[{}]]></value></column><column  name=\"支付状态\"><value><![CDATA[{}]]></value></column><column  name=\"支付信息\"><value><![CDATA[{}]]></value></column><column  name=\"支付申请状态\"><value><![CDATA[{}]]></value></column><column  name=\"成功标记\"><value><![CDATA[{}]]></value></column><column  name=\"流程标题\"><value><![CDATA[{}]]></value></column><column  name=\"请款主体\"><value><![CDATA[{}]]></value></column><column  name=\"收款对象\"><value><![CDATA[{}]]></value></column><column  name=\"金额\"><value><![CDATA[{}]]></value></column><column  name=\"CBS支付申请单号\"><value><![CDATA[{}]]></value></column></values><subForms/></formExport></forms>";
    }
}
